# Install and load the map libraries

# Install libraries if necessary.
install.packages(c("ggplot2", "maptools", "maps", "mapproj", "grid", 
                   "raster", "rgdal"))

library(ggplot2)
library(maptools)

# enable gpclib
gpclibPermit()

library(maps)
library(mapproj)
library(grid)
library(raster)
library(rgdal)

# Get level 0 (i.e. JUST hte contry boundary) data
Canada <- getData("GADM", country="CAN", level=0) # download CAN level 0 map 

# Get level 1 data: Provinces
Province <- getData("GADM", country="CAN", level = 1) 

# Select just NL
NL <- (Province[Province$NAME_1=="Newfoundland and Labrador",]) 
NS <- (Province[Province$NAME_1=="Nova Scotia",]) 
QC <- (Province[Province$NAME_1=="Qubec",]) 
PE <- (Province[Province$NAME_1=="Prince Edward Island",])

##################################
# Load shapefiles for NAFO zones #
##################################

NAFO <- readOGR("./data/shapefiles/Divisions.shp") 
  # Divisions.shp downloaded from https://www.nafo.int/Data/GIS

#######################
# Plot NAFO Map of NL #
#######################

latmin <- 42.50
latmax <- 57.50
longmin <- -62.50
longmax <- -47.50

b <- ggplot() +
  geom_polygon(data=NL, aes(long, lat, group=group),
               colour="grey10",fill="#fff7bc") +
  geom_polygon(data=NS, aes(long, lat, group=group),
               colour="grey10",fill="gray90") +
  geom_polygon(data=QC, aes(long, lat, group=group),
               colour="grey10",fill="gray90") +
  geom_polygon(data=PE, aes(long, lat, group=group),
               colour="grey10",fill="gray90") +
  geom_path(data=NAFO, aes(long, lat, group=group)) +
  annotate("text", x = coordinates(NAFO)[,1], 
           y = coordinates(NAFO)[,2], 
           label=NAFO[["ZONE"]]) +
  coord_map(xlim=c(longmin, longmax), # Set the axes max and min
            ylim=c(latmin, latmax)) +
  xlab("Longitude") +
  ylab("Latitude") +
  theme_bw() +
  theme(axis.text=element_text(size=12), axis.title = element_text(size=14)) +
  # Replace X and Y positives and negatives with degree N and degree W respectively
  scale_x_continuous(breaks=seq(longmin,longmax, 5),  # absolute value eliminates negative
                     labels=c(paste(abs(seq(longmin,longmax, 5)),"", sep=""))) + 
  scale_y_continuous(breaks=seq(latmin,latmax, 5), 
                     labels=c(paste(seq(latmin,latmax, 5), "", sep=""))) 

b

ggsave("Fig_23.png", width = 4, height = 6, units = "in", dpi = 300)

# Citations
citation ("ggplot2")
citation ("maptools")
citation ("maps")
citation ("mapproj")
citation ("grid")
citation ("rgdal")
citation ("raster")
citation ()
